@@ -117,6 +117,7 @@ bool AppearanceManager::init()
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::TimeUpdate, this, &AppearanceManager::handleTimeUpdate);
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::HandleForSleep, this, &AppearanceManager::handlePrepareForSleep);
 
+    initDtkSizeMode();
     initGlobalTheme();
 
     QVector<QSharedPointer<Theme>> iconList = m_subthemes->listIconThemes();
@@ -389,6 +390,13 @@ void AppearanceManager::handleSettingDConfigChange(QString key)
                 break;
             }
             utils::writeWallpaperConfig(wallpaper);
+        } else if (key == DDTKSIZEMODE) {
+            type = TYPEDTKSIZEMODE;
+            bool ok = false;
+            int mode = m_settingDconfig.value(key).toInt(&ok);
+            if (ok) {
+                doSetDTKSizeMode(mode);
+            }
         } else {
             return;
         }
@@ -554,6 +562,14 @@ void AppearanceManager::setMonospaceFont(QString value)
     }
 }
 
+void AppearanceManager::setDTKSizeMode(int value)
+{
+    if (value != m_property->dtkSizeMode && m_settingDconfig.isValid()) {
+        m_settingDconfig.setValue(DDTKSIZEMODE, value);
+        m_property->dtkSizeMode = value;
+    }
+}
+
 void AppearanceManager::setWindowRadius(int value)
 {
     if (value != m_property->windowRadius && m_xSetting) {
@@ -1514,7 +1530,15 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
     } else if (type == TYPEWALLPAPER) {
         doSetCurrentWorkspaceBackground(value);
         updateValut = true;
+    } else if (type == TYPEDTKSIZEMODE) {
+        bool ok = false;
+        int mode = value.toInt(&ok);
+        if (ok) {
+            QString fontSizeKey = GSKEYFONTSIZE;
+            doSetDTKSizeMode(mode);
+        }
     }
+
     if (updateValut) {
         updateCustomTheme(type, value);
     }
@@ -1734,6 +1758,10 @@ QString AppearanceManager::getWallpaperUri(const QString &index, const QString &
     return wallpaper;
 }
 
+void AppearanceManager::initDtkSizeMode(){
+    m_dbusProxy->SetInteger("DTK/SizeMode",m_property->dtkSizeMode);
+}
+
 void AppearanceManager::initGlobalTheme()
 {
     QVector<QSharedPointer<Theme>> globalList = m_subthemes->listGlobalThemes();
@@ -1827,6 +1855,13 @@ QString AppearanceManager::doGetWorkspaceBackgroundForMonitor(const int &index,
     return getWallpaperUri(QString::number(index), strMonitorName);
 }
 
+void AppearanceManager::doSetDTKSizeMode(int value) {
+    if (value != m_property->dtkSizeMode) {
+        setDTKSizeMode(value);
+        m_dbusProxy->SetInteger("DTK/SizeMode",value);
+    }
+}
+
 void AppearanceManager::autoChangeBg(QString monitorSpace, QDateTime date)
 {
     qDebug() << "autoChangeBg: " << monitorSpace << ", " << date;
